@@ -240,6 +240,7 @@
 
            ;; propspec.lisp
            #:in-consfig
+           #:no-consfig
            #:propspec-systems
            #:propspec-props
            #:make-propspec
@@ -255,6 +256,7 @@
            #:with-requirements
            #:silent-seqprops
            #:unapply
+           #:unapplied
            #:desc
            #:on-change
            #:on-apply-change
@@ -824,11 +826,13 @@
                              (#:service   #:consfigurator.property.service)
                              (#:apt       #:consfigurator.property.apt)
                              (#:os        #:consfigurator.property.os)
-                             (#:file      #:consfigurator.property.file))
+                             (#:file      #:consfigurator.property.file)
+                             (#:user      #:consfigurator.property.user))
            (:export #:installed
                     #:reloaded
                     #:main-configured
-                    #:mapped-file))
+                    #:mapped-file
+                    #:daemon-socket-directory))
 
   (package :consfigurator.property.cron
            (:local-nicknames (#:re        #:cl-ppcre)
@@ -847,6 +851,7 @@
            (:export #:installed
                     #:agree-tos
                     #:certificate-obtained
+                    #:certificate-obtained-standalone
                     #:fullchain-for
                     #:chain-for
                     #:certificate-for
@@ -998,4 +1003,6 @@
   (package :consfigurator.data.ssh-askpass
            (:local-nicknames (#:re   #:cl-ppcre)))
 
-  (package :consfigurator.data.local-file))
+  (package :consfigurator.data.local-file)
+
+  (package :consfigurator.data.files-tree))
