@@ -95,7 +95,10 @@ additional lines to add to the Apache configuration for both the HTTP and
 HTTPS virtual hosts; ADDITIONAL-CONFIG-HTTPS are additional lines to be added
 only to the HTTPS virtual host.
 
-Unapplying removes the Apache site config but leaves the certificate behind."
+Unapplying removes the Apache site config but leaves the certificate behind.
+
+The current implementation does not install a certificate renewal hook to
+restart Apache."
   `(with-unapply
      (network:aliases ,domain ,@aliases)
      (mod-enabled "ssl")
@@ -133,14 +136,14 @@ Unapplying removes the Apache site config but leaves the certificate behind."
                      ,(strcat "ServerName " name ":80")
                      ,@initial
                      "RewriteEngine On"
-                     "RewriteRule ^/.well-known/(.*) - [L]"
+                     "RewriteRule ^/.well-known/acme-challenge.* - [L]"
                      ;; redirect everything else to https
-                     ,(strcat "RewriteRule ^/(.*) https://" name "/$1 [L,R,NE]")
+                     "RewriteRule (.*) https://%{SERVER_NAME}$1 [R=301,L,NE]"
                      ,@additional-config
                      "</VirtualHost>")))))
      (on-change (lets-encrypt:certificate-obtained
                  ,agree-tos ,htdocs ,domain ,@aliases)
        (reloaded))
      :unapply
-     (unapply (site-enabled ,domain))
-     (unapply (site-available ,domain ""))))
+     (unapplied (site-enabled ,domain))
+     (unapplied (site-available ,domain ""))))
